@@ -10,21 +10,22 @@ from functools import partial
 
 from PyQt5.Qt import (QMenu, Qt, QInputDialog, QToolButton, QDialog,
         QDialogButtonBox, QGridLayout, QLabel, QLineEdit, QIcon, QSize,
-        QCoreApplication, pyqtSignal, QVBoxLayout, QTimer)
+        QCoreApplication, pyqtSignal, QVBoxLayout, QTimer, QAction)
 
 from calibre import isbytestring, sanitize_file_name_unicode
-from calibre.constants import (filesystem_encoding, iswindows,
-        get_portable_base)
+from calibre.constants import (filesystem_encoding, iswindows, get_portable_base, isportable)
 from calibre.utils.config import prefs, tweaks
 from calibre.utils.icu import sort_key
 from calibre.gui2 import (gprefs, warning_dialog, Dispatcher, error_dialog,
     question_dialog, info_dialog, open_local_file, choose_dir)
 from calibre.gui2.actions import InterfaceAction
 
+
 def db_class():
     from calibre.db.legacy import LibraryDatabase
     return LibraryDatabase
 
+
 class LibraryUsageStats(object):  # {{{
 
     def __init__(self):
@@ -96,6 +97,7 @@ class LibraryUsageStats(object):  # {{{
         self.write_stats()
 # }}}
 
+
 class MovedDialog(QDialog):  # {{{
 
     def __init__(self, stats, location, parent=None):
@@ -152,6 +154,7 @@ class MovedDialog(QDialog):  # {{{
         QDialog.accept(self)
 # }}}
 
+
 class BackupStatus(QDialog):  # {{{
 
     def __init__(self, gui):
@@ -208,6 +211,8 @@ class ChooseLibraryAction(InterfaceAction):
     def genesis(self):
         self.count_changed(0)
         self.action_choose = self.menuless_qaction
+        self.action_exim = ac = QAction(_('Export/Import all calibre data'), self.gui)
+        ac.triggered.connect(self.exim_data)
 
         self.stats = LibraryUsageStats()
         self.popup_type = (QToolButton.InstantPopup if len(self.stats.stats) > 1 else
@@ -233,6 +238,7 @@ class ChooseLibraryAction(InterfaceAction):
             self.choose_menu.addAction(ac)
             self.delete_menu = QMenu(_('Remove library'))
             self.delete_menu_action = self.choose_menu.addMenu(self.delete_menu)
+            self.choose_menu.addAction(self.action_exim)
         else:
             self.choose_menu.addAction(ac)
 
@@ -281,6 +287,20 @@ class ChooseLibraryAction(InterfaceAction):
     def pick_random(self, *args):
         self.gui.iactions['Pick Random Book'].pick_random()
 
+    def exim_data(self):
+        if isportable:
+            return error_dialog(self.gui, _('Cannot export/import'), _(
+                'You are running calibre portable, all calibre data is already in the'
+                ' calibre portable folder. Export/Import is unavailable.'), show=True)
+        if self.gui.job_manager.has_jobs():
+            return error_dialog(self.gui, _('Cannot Export/Import'),
+                    _('Cannot export/import data while there are running jobs.'), show=True)
+        from calibre.gui2.dialogs.exim import EximDialog
+        d = EximDialog(parent=self.gui)
+        if d.exec_() == d.Accepted:
+            if d.restart_needed:
+                self.gui.iactions['Restart'].restart()
+
     def library_name(self):
         db = self.gui.library_view.model().db
         path = db.library_path
@@ -585,12 +605,11 @@ class ChooseLibraryAction(InterfaceAction):
         self.pre_choose_dialog_location = location
         c = ChooseLibrary(db, self.choose_library_callback, self.gui)
         c.exec_()
-        self.choose_dialog_library_renamed = getattr(c, 'library_renamed', False)
 
-    def choose_library_callback(self, newloc, copy_structure=False):
+    def choose_library_callback(self, newloc, copy_structure=False, library_renamed=False):
         self.gui.library_moved(newloc, copy_structure=copy_structure,
                 allow_rebuild=True)
-        if getattr(self, 'choose_dialog_library_renamed', False):
+        if library_renamed:
             self.stats.rename(self.pre_choose_dialog_location, prefs['library_path'])
         self.build_menus()
         self.gui.iactions['Copy To Library'].build_menus()
