@@ -45,6 +45,7 @@ OK_COLOR = 'rgba(0, 255, 0, 12%)'
 ERR_COLOR = 'rgba(255, 0, 0, 12%)'
 INDICATOR_SHEET = 'QLineEdit { color: black; background-color: %s }'
 
+
 def save_dialog(parent, title, msg, det_msg=''):
     d = QMessageBox(parent)
     d.setWindowTitle(title)
@@ -52,6 +53,7 @@ def save_dialog(parent, title, msg, det_msg=''):
     d.setStandardButtons(QMessageBox.Yes | QMessageBox.No | QMessageBox.Cancel)
     return d.exec_()
 
+
 def clean_text(x):
     return re.sub(r'\s', ' ', x.strip())
 
@@ -77,6 +79,7 @@ class BasicMetadataWidget(object):
         return property(fget=fget, fset=fset)
 '''
 
+
 class ToMetadataMixin(object):
 
     FIELD_NAME = None
@@ -108,6 +111,7 @@ class ToMetadataMixin(object):
         else:
             self.setEditText(text)
 
+
 def make_undoable(spinbox):
     'Add a proper undo/redo capability to spinbox which must be a sub-class of QAbstractSpinBox'
 
@@ -181,6 +185,8 @@ def make_undoable(spinbox):
     return UndoableSpinbox
 
 # Title {{{
+
+
 class TitleEdit(EnLineEdit, ToMetadataMixin):
 
     TITLE_ATTR = FIELD_NAME = 'title'
@@ -234,6 +240,7 @@ class TitleEdit(EnLineEdit, ToMetadataMixin):
     def break_cycles(self):
         self.dialog = None
 
+
 class TitleSortEdit(TitleEdit, ToMetadataMixin):
 
     TITLE_ATTR = FIELD_NAME = 'title_sort'
@@ -314,6 +321,8 @@ class TitleSortEdit(TitleEdit, ToMetadataMixin):
 # }}}
 
 # Authors {{{
+
+
 class AuthorsEdit(EditWithComplete, ToMetadataMixin):
 
     TOOLTIP = ''
@@ -422,6 +431,7 @@ class AuthorsEdit(EditWithComplete, ToMetadataMixin):
         except:
             pass
 
+
 class AuthorSortEdit(EnLineEdit, ToMetadataMixin):
 
     TOOLTIP = _('Specify how the author(s) of this book should be sorted. '
@@ -486,10 +496,13 @@ class AuthorSortEdit(EnLineEdit, ToMetadataMixin):
         self.first_time = False
         self.update_state()
 
+    def author_sort_from_authors(self, authors):
+        return self.db.new_api.author_sort_from_authors(authors, key_func=lambda x: x)
+
     def update_state(self, *args):
         au = unicode(self.authors_edit.text())
         au = re.sub(r'\s+et al\.$', '', au)
-        au = self.db.author_sort_from_authors(string_to_authors(au))
+        au = self.author_sort_from_authors(string_to_authors(au))
 
         normal = au == self.current_val
         col = OK_COLOR if normal else ERR_COLOR
@@ -517,7 +530,7 @@ class AuthorSortEdit(EnLineEdit, ToMetadataMixin):
         au = unicode(self.authors_edit.text())
         au = re.sub(r'\s+et al\.$', '', au).strip()
         authors = string_to_authors(au)
-        self.current_val = self.db.author_sort_from_authors(authors)
+        self.current_val = self.author_sort_from_authors(authors)
 
     def author_to_sort(self, *args):
         au = unicode(self.authors_edit.text())
@@ -568,6 +581,8 @@ class AuthorSortEdit(EnLineEdit, ToMetadataMixin):
 # }}}
 
 # Series {{{
+
+
 class SeriesEdit(EditWithComplete, ToMetadataMixin):
 
     TOOLTIP = _('List of known series. You can add new series.')
@@ -704,6 +719,7 @@ class SeriesIndexEdit(make_undoable(QDoubleSpinBox), ToMetadataMixin):
 
 # }}}
 
+
 class BuddyLabel(QLabel):  # {{{
 
     def __init__(self, buddy):
@@ -714,6 +730,7 @@ class BuddyLabel(QLabel):  # {{{
 
 # Formats {{{
 
+
 class Format(QListWidgetItem):
 
     def __init__(self, parent, ext, size, path=None, timestamp=None):
@@ -730,6 +747,7 @@ class Format(QListWidgetItem):
             self.setToolTip(text)
             self.setStatusTip(text)
 
+
 class OrigAction(QAction):
 
     restore_fmt = pyqtSignal(object)
@@ -742,6 +760,7 @@ class OrigAction(QAction):
     def _triggered(self):
         self.restore_fmt.emit(self.fmt)
 
+
 class FormatList(_FormatList):
 
     restore_fmt = pyqtSignal(object)
@@ -770,6 +789,7 @@ class FormatList(_FormatList):
                 self.takeItem(i)
                 break
 
+
 class FormatsManager(QWidget):
 
     def __init__(self, parent, copy_fmt):
@@ -783,7 +803,7 @@ class FormatsManager(QWidget):
         self.cover_from_format_button = QToolButton(self)
         self.cover_from_format_button.setToolTip(
                 _('Set the cover for the book from the selected format'))
-        self.cover_from_format_button.setIcon(QIcon(I('book.png')))
+        self.cover_from_format_button.setIcon(QIcon(I('default_cover.png')))
         self.cover_from_format_button.setIconSize(QSize(32, 32))
 
         self.metadata_from_format_button = QToolButton(self)
@@ -1005,6 +1025,7 @@ class FormatsManager(QWidget):
         self.temp_files = []
 # }}}
 
+
 class Cover(ImageView):  # {{{
 
     download_cover = pyqtSignal()
@@ -1161,6 +1182,7 @@ class Cover(ImageView):  # {{{
     def current_val(self):
         def fget(self):
             return self._cdata
+
         def fset(self, cdata):
             self._cdata = None
             self.cdata_before_trim = None
@@ -1203,6 +1225,7 @@ class Cover(ImageView):  # {{{
 
 # }}}
 
+
 class CommentsEdit(Editor, ToMetadataMixin):  # {{{
 
     FIELD_NAME = 'comments'
@@ -1212,6 +1235,7 @@ class CommentsEdit(Editor, ToMetadataMixin):  # {{{
     def current_val(self):
         def fget(self):
             return self.html
+
         def fset(self, val):
             if not val or not val.strip():
                 val = ''
@@ -1231,6 +1255,7 @@ class CommentsEdit(Editor, ToMetadataMixin):  # {{{
             db.set_comment(id_, self.current_val, notify=False, commit=False)
 # }}}
 
+
 class RatingEdit(RatingEditor, ToMetadataMixin):  # {{{
     LABEL = _('&Rating:')
     TOOLTIP = _('Rating of this book. 0-5 stars')
@@ -1245,6 +1270,7 @@ class RatingEdit(RatingEditor, ToMetadataMixin):  # {{{
     def current_val(self):
         def fget(self):
             return self.rating_value
+
         def fset(self, val):
             self.rating_value = val
         return property(fget=fget, fset=fset)
@@ -1263,6 +1289,7 @@ class RatingEdit(RatingEditor, ToMetadataMixin):  # {{{
 
 # }}}
 
+
 class TagsEdit(EditWithComplete, ToMetadataMixin):  # {{{
     LABEL = _('Ta&gs:')
     TOOLTIP = '<p>'+_('Tags categorize the book. This is particularly '
@@ -1272,7 +1299,7 @@ class TagsEdit(EditWithComplete, ToMetadataMixin):  # {{{
 
     def __init__(self, parent):
         EditWithComplete.__init__(self, parent)
-        self.lineEdit().setMaxLength(65536)  # see https://bugs.launchpad.net/bugs/1569388
+        self.lineEdit().setMaxLength(655360)  # see https://bugs.launchpad.net/bugs/1630944
         self.books_to_refresh = set([])
         self.setToolTip(self.TOOLTIP)
         self.setWhatsThis(self.TOOLTIP)
@@ -1281,6 +1308,7 @@ class TagsEdit(EditWithComplete, ToMetadataMixin):  # {{{
     def current_val(self):
         def fget(self):
             return [clean_text(x) for x in unicode(self.text()).split(',')]
+
         def fset(self, val):
             if not val:
                 val = []
@@ -1327,6 +1355,7 @@ class TagsEdit(EditWithComplete, ToMetadataMixin):  # {{{
 
 # }}}
 
+
 class LanguagesEdit(LE, ToMetadataMixin):  # {{{
 
     LABEL = _('&Languages:')
@@ -1341,6 +1370,7 @@ class LanguagesEdit(LE, ToMetadataMixin):  # {{{
     def current_val(self):
         def fget(self):
             return self.lang_codes
+
         def fset(self, val):
             self.set_lang_codes(val, self.allow_undo)
         return property(fget=fget, fset=fset)
@@ -1370,6 +1400,7 @@ class LanguagesEdit(LE, ToMetadataMixin):  # {{{
 
 # Identifiers {{{
 
+
 class Identifiers(Dialog):
 
     def __init__(self, identifiers, parent=None):
@@ -1415,6 +1446,7 @@ class Identifiers(Dialog):
             return
         Dialog.accept(self)
 
+
 class IdentifiersEdit(QLineEdit, ToMetadataMixin):
     LABEL = _('I&ds:')
     BASE_TT = _('Edit the identifiers for this book. '
@@ -1457,9 +1489,11 @@ class IdentifiersEdit(QLineEdit, ToMetadataMixin):
                             c = v
                     ans[itype] = c
             return ans
+
         def fset(self, val):
             if not val:
                 val = {}
+
             def keygen(x):
                 x = x[0]
                 if x == 'isbn':
@@ -1518,6 +1552,7 @@ class IdentifiersEdit(QLineEdit, ToMetadataMixin):
 
 # }}}
 
+
 class ISBNDialog(QDialog):  # {{{
 
     def __init__(self, parent, txt):
@@ -1570,6 +1605,7 @@ class ISBNDialog(QDialog):  # {{{
 
 # }}}
 
+
 class PublisherEdit(EditWithComplete, ToMetadataMixin):  # {{{
     LABEL = _('&Publisher:')
     FIELD_NAME = 'publisher'
@@ -1621,12 +1657,14 @@ class PublisherEdit(EditWithComplete, ToMetadataMixin):  # {{{
 
 # DateEdit {{{
 
+
 class CalendarWidget(QCalendarWidget):
 
     def showEvent(self, ev):
         if self.selectedDate().year() == UNDEFINED_DATE.year:
             self.setSelectedDate(QDate.currentDate())
 
+
 class DateEdit(make_undoable(QDateTimeEdit), ToMetadataMixin):
 
     TOOLTIP = ''
@@ -1662,6 +1700,7 @@ class DateEdit(make_undoable(QDateTimeEdit), ToMetadataMixin):
     def current_val(self):
         def fget(self):
             return qt_to_dt(self.dateTime(), as_utc=False)
+
         def fset(self, val):
             if val is None or is_date_undefined(val):
                 val = UNDEFINED_DATE
@@ -1695,6 +1734,7 @@ class DateEdit(make_undoable(QDateTimeEdit), ToMetadataMixin):
         else:
             return super(DateEdit, self).keyPressEvent(ev)
 
+
 class PubdateEdit(DateEdit):
     LABEL = _('Publishe&d:')
     FMT = 'MMM yyyy'
